@@ -1,24 +1,43 @@
-#!/usr/bin/perl
 use strict;
 use warnings;
-
 package App::Addex::AddressBook;
+{
+  $App::Addex::AddressBook::VERSION = '0.024';
+}
+# ABSTRACT: the address book that addex will consult
 
 use App::Addex::Entry;
 
 use Carp ();
 
+
+sub new {
+  my ($class, $arg) = @_;
+  Carp::croak "no addex argument provided" unless $arg->{addex};
+  bless { addex => $arg->{addex} } => $class;
+}
+
+
+sub addex { $_[0]->{addex} }
+
+
+sub entries {
+  Carp::confess "no behavior defined for virtual method entries";
+}
+
+1;
+
+__END__
+
+=pod
+
 =head1 NAME
 
 App::Addex::AddressBook - the address book that addex will consult
 
 =head1 VERSION
 
-version 0.023
-
-=cut
-
-our $VERSION = '0.023';
+version 0.024
 
 =head1 METHODS
 
@@ -33,24 +52,12 @@ Valid arguments are:
 
   addex - required; the App::Addex object using this address book
 
-=cut
-
-sub new {
-  my ($class, $arg) = @_;
-  Carp::croak "no addex argument provided" unless $arg->{addex};
-  bless { addex => $arg->{addex} } => $class;
-}
-
 =head2 addex
 
   my $addex = $addr_book->addex;
 
 This returns the App::Addex object with which the address book is associated.
 
-=cut
-
-sub addex { $_[0]->{addex} }
-
 =head2 entries
 
   my @entries = $addex->entries;
@@ -61,29 +68,15 @@ objects.  Its behavior in scalar context is not yet defined.
 This method should be implemented by a address-book-implementation-specific
 subclass.
 
-=cut
-
-sub entries {
-  Carp::confess "no behavior defined for virtual method entries";
-}
-
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2006 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2006-2007 Ricardo Signes, all rights reserved.
-
-This program is free software; you may redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
