@@ -1,8 +1,46 @@
-#!/usr/bin/perl
 use strict;
 use warnings;
-
 package App::Addex::Entry::EmailAddress;
+{
+  $App::Addex::Entry::EmailAddress::VERSION = '0.024';
+}
+# ABSTRACT: an address book entry's email address
+
+
+sub new {
+  my ($class, $arg) = @_;
+
+  $arg = { address => $arg } if not ref $arg;
+  undef $arg->{label} if defined $arg->{label} and not length $arg->{label};
+
+  for (qw(sends receives)) {
+    $arg->{$_} = 1 unless exists $arg->{$_};
+  }
+
+  bless $arg => $class;
+}
+
+
+use overload '""' => 'address';
+
+sub address {
+  $_[0]->{address}
+}
+
+
+sub label {
+  $_[0]->{label}
+}
+
+
+sub sends    { $_[0]->{sends} }
+sub receives { $_[0]->{receives} }
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
@@ -10,11 +48,7 @@ App::Addex::Entry::EmailAddress - an address book entry's email address
 
 =head1 VERSION
 
-version 0.023
-
-=cut
-
-our $VERSION = '0.023';
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -38,69 +72,27 @@ Valid arguments are:
   sends    - if true, this address may send mail; default: true
   receives - if true, this address may receive mail; default: true
 
-=cut
-
-sub new {
-  my ($class, $arg) = @_;
-
-  $arg = { address => $arg } if not ref $arg;
-  undef $arg->{label} if defined $arg->{label} and not length $arg->{label};
-
-  for (qw(sends receives)) {
-    $arg->{$_} = 1 unless exists $arg->{$_};
-  }
-
-  bless $arg => $class;
-}
-
 =head2 address
 
 This method returns the email address as a string.
 
-=cut
-
-use overload '""' => 'address';
-
-sub address {
-  $_[0]->{address}
-}
-
 =head2 label
 
 This method returns the address label, if any.
 
-=cut
-
-sub label {
-  $_[0]->{label}
-}
-
 =head2 sends
 
 =head2 receives
 
-=cut
-
-sub sends    { $_[0]->{sends} }
-sub receives { $_[0]->{receives} }
-
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2006 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2006-2007 Ricardo Signes, all rights reserved.
-
-This program is free software; you may redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
