@@ -1,24 +1,60 @@
-#!/usr/bin/perl
 use strict;
 use warnings;
 
 package App::Addex::Output::ToFile;
-use App::Addex::Output;
-BEGIN { our @ISA = 'App::Addex::Output' }
+{
+  $App::Addex::Output::ToFile::VERSION = '0.024';
+}
+use parent 'App::Addex::Output';
+# ABSTRACT: base class for output plugins that write to files
 
 use Carp ();
 
+
+sub new {
+  my ($class, $arg) = @_;
+
+  Carp::croak "no filename argument given for $class" unless $arg->{filename};
+
+  my $self = $class->SUPER::new;
+
+  open my $fh, '>', $arg->{filename}
+    or Carp::croak "couldn't open output file $arg->{filename}: $!";
+
+  binmode($fh, ':encoding(utf8)');
+
+  $self->{fh} = $fh;
+
+  return $self;
+}
+
+
+sub output {
+  my ($self, $line) = @_;
+
+  print { $self->{fh} } "$line\n"
+    or Carp::croak "couldn't write to output file: $!";
+}
+
+sub finalize {
+  # We'll just delete this ref and let garbage collection cause closing if
+  # needed. -- rjbs, 2007-11-05
+  delete $_[0]->{fh};
+}
+
+1;
+
+__END__
+
+=pod
+
 =head1 NAME
 
 App::Addex::Output::ToFile - base class for output plugins that write to files
 
 =head1 VERSION
 
-version 0.023
-
-=cut
-
-our $VERSION = '0.023';
+version 0.024
 
 =head1 DESCRIPTION
 
@@ -39,63 +75,21 @@ Valid arguments are:
 
   filename - the file to which to write configuration (required)
 
-=cut
-
-sub new {
-  my ($class, $arg) = @_;
-
-  Carp::croak "no filename argument given for $class" unless $arg->{filename};
-
-  my $self = $class->SUPER::new;
-
-  open my $fh, '>', $arg->{filename}
-    or Carp::croak "couldn't open output file $arg->{filename}: $!";
-
-  binmode($fh, ':encoding(utf8)');
-
-  $self->{fh} = $fh;
-
-  return $self;
-}
-
 =head2 output
 
   $outputter->output($string);
 
 This method appends the given string to the output file, adding a newline.
 
-=cut
-
-sub output {
-  my ($self, $line) = @_;
-
-  print { $self->{fh} } "$line\n"
-    or Carp::croak "couldn't write to output file: $!";
-}
-
-sub finalize {
-  # We'll just delete this ref and let garbage collection cause closing if
-  # needed. -- rjbs, 2007-11-05
-  delete $_[0]->{fh};
-}
-
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2006 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2006-2007 Ricardo Signes, all rights reserved.
-
-This program is free software; you may redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
